@@ -76,6 +76,7 @@ cmp (){
 
 # real tests
 tests='
+makefiles2deps
 pkgsrc-dewey
 pkg_summary2leaves
 pkg_grep_summary
@@ -83,21 +84,23 @@ pkg_list_all_pkgs
 pkg_refresh_summary
 pkg_summary4view
 pkg_uniq_summary
-pkg_src_summary
 pkg_assignments2pkgpath
 pkg_src_fetch_var
-pkg_micro_src_summary
 pkg_cmp_summary
 pkg_summary2deps
 pkg_lint_summary
 pkg_subgraph_deps
 pkg_bin_summary
-pkg_digger_backend
+pkg_digger_summary
+pkg_digger_installed
+pkg_micro_src_summary
+summary2multi_variants
+pkg_src_summary
 '
 
 normalize_version (){
      awk '
-    /^PKGNAME=/ {
+    /^PKGNAME[=:]/ {
         gsub(/(nb|alpha|beta|pre|rc|pl)[0-9]+$/, "")
         gsub(/[a-zA-Z]$/, "")
         gsub(/-[^-]*$/, "-X")
